@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 
-licence="""
+import os.path
+import os
+import pickle
+licence = """
     preferences is a a file of the project pymecavideo:
     a program to track moving points in a video frameset
     Copyright (C) 2007 Jean-Baptiste Butet <ashashiwa@gmail.com>
@@ -19,25 +22,21 @@ licence="""
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-#from Ui_preferences import Ui_Dialog
-from dbg import Dbg
-import vecteur, commands
-import pickle, os, os.path
+# from Ui_preferences import Ui_Dialog
+
 
 class Preferences:
     def __init__(self, parent):
-        
-        self.app=parent
-        self.app.dbg.p(3,"In : Preferences, preferences.py")
 
-        self.conffile=os.path.join(self.app._dir("conf"),"pymecavideo.conf")
+        self.app = parent
+        self.app.dbg.p(3, "In : Preferences, preferences.py")
+
+        self.conffile = os.path.join(self.app._dir("conf"), "pymecavideo.conf")
         # ajuste les valeurs par défaut
-        self.proximite=False
-        self.lastVideo=""
-        self.videoDir=os.getcwd()
-        self.niveauDbg=0 # niveau d'importance des messages de débogage
+        self.proximite = False
+        self.lastVideo = ""
+        self.videoDir = os.getcwd()
+        self.niveauDbg = 0  # niveau d'importance des messages de débogage
         # récupère les valeurs enregistrées
         self.load()
 
@@ -45,34 +44,31 @@ class Preferences:
         """
         Renvoie une chaîne représentant les préférences, lisible par un humain
         """
-        result=self.app.tr("Proximite de la souris %1").arg(self.proximite)
-        result +=self.app.tr("; derniere video %1").arg(self.lastVideo)
-        result +=self.app.tr("; videoDir %1").arg(self.videoDir)
-        return "%s" %result
+        result = self.app.tr(
+            "Proximite de la souris {0}").format(self.proximite)
+        result += self.app.tr("; derniere video {0}").format(self.lastVideo)
+        result += self.app.tr("; videoDir {0}").format(self.videoDir)
+        return "%s" % result
 
     def save(self):
         """
         Sauvegarde des préférences dans le fichier de configuration.
         """
-        f=open(self.conffile,"w")
-        self.app.dbg.p(6,"sauvegarde des preferences dans  %s" %self.conffile)
-        self.app.dbg.p(6, "%s" %self)
-        try : 
-	    self.lastVideo = unicode(self.lastVideo,'utf8')
-	except TypeError:
-	    pass
-        pickle.dump((self.proximite,self.lastVideo,self.videoDir),f)
+        f = open(self.conffile, "wb")
+        self.app.dbg.p(6, "sauvegarde des preferences dans  %s" %
+                       self.conffile)
+        self.app.dbg.p(6, "%s" % self)
+        pickle.dump((self.proximite, self.lastVideo, self.videoDir), f)
         f.close()
-        
+
     def load(self):
         if os.path.exists(self.conffile):
             try:
-                f=open(self.conffile,"r")
-                (self.proximite,self.lastVideo,self.videoDir) = pickle.load(f)
+                f = open(self.conffile, "rb")
+                (self.proximite, self.lastVideo, self.videoDir) = pickle.load(f)
                 f.close()
             except:
-                self.app.dbg.p(2,"erreur en lisant %s" %self.conffile)
-                self.app.dbg.p(2,"effacement du répertoire temporaire de pymecavideo")
+                self.app.dbg.p(2, "erreur en lisant %s" % self.conffile)
+                self.app.dbg.p(
+                    2, "effacement du répertoire temporaire de pymecavideo")
                 pass
-        
-        
