@@ -6,7 +6,7 @@
       This module is just an utility to manage the version number which
       is important for releases of pymecavideo
       
-    Copyright (C) 2008 Georges Khaznadar
+    Copyright (C) 2008-2018 Georges Khaznadar
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,14 +22,20 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+import os.path
+import gzip
+import re
+
 
 class version:
     def __init__(self, majeur, mineur, nuance=""):
-        self.majeur=majeur
-        self.mineur=mineur
-        self.nuance=nuance
+        self.majeur = majeur
+        self.mineur = mineur
+        self.nuance = nuance
+
     def __str__(self):
-        return "%s.%s%s" %(self.majeur,self.mineur, self.nuance)
+        return "%s.%s%s" % (self.majeur, self.mineur, self.nuance)
+
     def __repr__(self):
         return self.__str__()
 
@@ -37,10 +43,19 @@ class version:
 ###############################################################
 # la version courante, à incrémenter lors de changements
 ###############################################################
-Version=version(6,0,'')
+Version = version(7, 2, 'release1')
 ###############################################################
+# incrémentation automatique pour une distribution debian
+###############################################################
+packageName = "python3-mecavideo"
+changelog = os.path.join("/usr/share/doc", packageName, "changelog.Debian.gz")
+if os.path.exists(changelog):
+    with gzip.open(changelog) as chlog:
+        firstline = chlog.readline().strip().decode("utf-8")
+        m = re.match(r"^pymecavideo \((.*)\).*$", firstline)
+        if m:
+            Version = m.group(1)
 
 
-if __name__=="__main__":
-    print Version
-    
+if __name__ == "__main__":
+    print(Version)
