@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 """
     videotraj, a module for pymecavideo:
@@ -20,26 +20,31 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-import sys, os, thread, time, commands
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-from math import sqrt, acos, asin, pi, cos, sin, atan2
-from vecteur import vecteur
+from PyQt5.QtCore import QThread, pyqtSignal, QLocale, QTranslator, Qt, QSize, QTimer, QObject, QRect, QPoint, QPointF
+from PyQt5.QtGui import QKeySequence, QIcon, QPixmap, QImage, QPainter, QCursor, QPen, QColor
+from PyQt5.QtWidgets import QApplication, QMainWindow, QLabel, QWidget, QShortcut, QDesktopWidget, QLayout, QFileDialog, QTableWidgetItem, QInputDialog, QLineEdit, QMessageBox, QTableWidgetSelectionRange
+
 
 class Zoom_Croix(QWidget):
-    def __init__(self, parent,app):
-
+    def __init__(self, parent, app):
         QWidget.__init__(self, parent)
         self.parent = parent
         self.app = app
-        
+
         self.setEnabled(True)
         self.setGeometry(QRect(0, 0, 100, 100))
         self.setAutoFillBackground(False)
-        
+
     def paintEvent(self, event):
-                painter = QPainter()
-                painter.begin(self)
-                painter.setPen(Qt.red)
-                painter.drawLine(50, 0, 50, 100)
-                painter.drawLine(0, 50, 100, 50)
+        painter = QPainter()
+        painter.begin(self)
+        painter.setPen(Qt.red)
+        painter.drawLine(50, 0, 50, 45)
+        painter.drawLine(50, 55, 50, 100)
+        painter.drawLine(0, 50, 45, 50)
+        painter.drawLine(55, 50, 100, 50)
+
+        # fixe la couleur du crayon et la largeur pour le dessin - forme compactée
+        painter.setPen(QPen(QColor(255, 64, 255), 1))
+        # cf QPen(QBrush brush, float width, Qt.PenStyle style = Qt.SolidLine, Qt.PenCapStyle cap = Qt.SquareCap, Qt.PenJoinStyle join = Qt.BevelJoin)
+        painter.drawEllipse(QPointF(50, 50), 5, 5)
